@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """Auth class file."""
-
 import os
 import sys
 
@@ -450,6 +449,17 @@ class Auth(object):
             verbose=self.verbose,
         )
 
+    def gaia(self):
+        """Connect to Gaia."""
+        from bits.gaia import Gaia
+        settings = self.settings["gaia"]
+        return Gaia(
+            bigquery_imports_bucket=settings.get("bigquery_bucket"),
+            config_bucket=settings.get("config_bucket"),
+            firestore_imports_bucket=settings.get("firestore_bucket"),
+            verbose=self.verbose,
+        )
+
     def github(self, token=None):
         """Return an authenticated GitHub object."""
         from bitsapiclient.services.github import GitHub
